@@ -701,7 +701,10 @@ Adapt_buffer_convert(dc1394video_frame_t *in, dc1394video_frame_t *out)
     if (out->total_bytes>out->allocated_image_bytes) {
         free(out->image);
         out->image=(uint8_t*)malloc(out->total_bytes*sizeof(uint8_t));
-        out->allocated_image_bytes=out->total_bytes;
+        if (out->image)
+            out->allocated_image_bytes = out->total_bytes*sizeof(uint8_t);
+        else
+            out->allocated_image_bytes = 0;
     }
 
     // Copy padding bytes:
@@ -874,7 +877,10 @@ Adapt_buffer_stereo(dc1394video_frame_t *in, dc1394video_frame_t *out)
     if (out->total_bytes>out->allocated_image_bytes) {
         free(out->image);
         out->image=(uint8_t*)malloc(out->total_bytes*sizeof(uint8_t));
-        out->allocated_image_bytes=out->total_bytes;
+        if (out->image)
+            out->allocated_image_bytes = out->total_bytes*sizeof(uint8_t);
+        else
+            out->allocated_image_bytes = 0;
     }
 
     // Copy padding bytes:
